# coding: utf-8
from rest_framework.request import Request
from datetime import datetime, timedelta
from inspect_report.models import Tasks, CheckSession, RulesStat, SeatStat
from config.config import TABLE_PRE
import json
import logging
"""定时任务

参考：https://github.com/jgorset/django-kronos
"""
logger = logging.getLogger("app_file")


def rule_stat(start_date, end_date):
    """
    首页概述-违规项统计
    :return:
    """
    task_condition = {'hasCheck': 1, 'createdAt__gte': start_date, 'createdAt__lt': end_date}
    tasks = Tasks.objects.filter(**task_condition).values('id', 'name', 'sessionCollectionId')
    stat_count = 0
    for t in tasks:
        table_name = TABLE_PRE + t['sessionCollectionId']
        tn = CheckSession.set_table(table_name)
        session_condition = {'taskId': t['id'], 'violationRuleCount__gt': 0}
        checks = tn.objects.filter(**session_condition).values('id', 'checkResult', 'agentName', 'customName', 'score',
                                                               'remainTime', 'taskId', 'sessionId')
        for check in checks:
            result = check['checkResult']
            if result:
                data = json.loads(result)
                for d in data:
                    if 'isViolation' in d.keys() and d['isViolation'] and 'rule' in d.keys() and 'name' in d['rule'].keys():
                        name = d['rule']['name']
                        rd = RulesStat()
                        rd.create_date = start_date
                        rd.sessionCollectionId = t['sessionCollectionId']
                        rd.rule = name
                        rd.rule_num = 1
                        rd.task = t['name'].split('_')[0]
                        rd.agentName = check['agentName']
                        rd.customName = check['customName']
                        rd.score = check['score']
                        rd.remainTime = check['remainTime']
                        rd.taskId = check['taskId']
                        rd.sessionId = check['sessionId']
                        rd.session_table_id = check['id']
                        rd.save()
                        stat_count += 1
                        logger.info('统计数量为：%s' % stat_count)


def seat_stat(start_date, end_date):
    """
    首页概述-违规项统计
    :return:
    """

    task_condition = {'hasCheck': 1, 'createdAt__gte': start_date, 'createdAt__lt': end_date}
    tasks = Tasks.objects.filter(**task_condition).values('id', 'name', 'sessionCollectionId')
    for t in tasks:
        table_name = TABLE_PRE + t['sessionCollectionId']
        tn = CheckSession.set_table(table_name)
        session_condition = {'taskId': t['id']}
        checks = tn.objects.filter(**session_condition).values('id', 'agentName', 'taskId', 'violationRuleCount')
        for check in checks:
            seat_condition = {'create_date': start_date, 'agentName': check['agentName']}
            seats = SeatStat.objects.filter(**seat_condition)
            if seats:
                seat = seats[0]
                seat.total_session += 1
                seat.validate_session += 1 if check['violationRuleCount'] > 0 else 0
                seat.save()
            else:
                seat = SeatStat()
                seat.create_date = start_date
                seat.agentName = check['agentName']
                seat.taskId = check['taskId']
                seat.task = t['name'].split('_')[0]
                seat.sessionCollectionId = t['sessionCollectionId']
                seat.total_session = 1
                seat.validate_session = 1 if check['violationRuleCount'] > 0 else 0
                seat.save()
